@@ -1,12 +1,12 @@
-#!/usr/bin/perl
-
 package Data::Stream::Bulk;
+{
+  $Data::Stream::Bulk::VERSION = '0.08';
+}
 use Moose::Role;
+# ABSTRACT: N at a time iteration API
 
 use namespace::clean -except => 'meta';
 
-our $VERSION = "0.07";
-
 requires qw(next is_done);
 
 sub items {
@@ -65,16 +65,26 @@ sub filter {
 	);
 }
 
+sub chunk {
+    my ( $self, $chunk_size ) = @_;
+
+    return Data::Stream::Bulk::Chunked->new(
+        chunk_size => $chunk_size,
+        stream     => $self,
+    );
+}
+
 sub loaded { 0 }
 
 # load it *after* the entire role is defined
 require Data::Stream::Bulk::Cat;
+require Data::Stream::Bulk::Chunked;
 require Data::Stream::Bulk::Nil;
 require Data::Stream::Bulk::Filter;
 
-__PACKAGE__
+__PACKAGE__;
+
 
-__END__
 
 =pod
 
@@ -82,6 +92,10 @@ __END__
 
 Data::Stream::Bulk - N at a time iteration API
 
+=head1 VERSION
+
+version 0.08
+
 =head1 SYNOPSIS
 
 	# get a bulk stream from somewere
@@ -178,6 +192,11 @@ Returns a possibly new stream with the filtering layered.
 C<$filter> is invoked once per block and should return an array reference to
 the filtered block.
 
+=item chunk $chunk_size
+
+Chunks the input stream so that each block returned by C<next> will have at
+least C<$chunk_size> items.
+
 =item loaded
 
 Should be overridden to return true if all the items are already realized (e.g.
@@ -207,6 +226,10 @@ with larger data sets.
 
 Callback driven iteration.
 
+=item L<Data::Stream::Bulk::Chunked>
+
+Wrapper to return larger blocks from an existing stream.
+
 =item L<Data::Stream::Bulk::DBI>
 
 Bulk fetching of data from L<DBI> statement handles.
@@ -215,6 +238,10 @@ Bulk fetching of data from L<DBI> statement handles.
 
 L<DBIx::Class::ResultSet> iteration.
 
+=item L<Data::Stream::Bulk::FileHandle>
+
+Iterates over lines in a text file.
+
 =item L<Data::Stream::Bulk::Nil>
 
 An empty result set.
@@ -273,13 +300,17 @@ L<http://github.com/nothingmuch/data-stream-bulk/>.
 
 =head1 AUTHOR
 
-Yuval Kogman E<lt>nothingmuch@woobling.orgE<gt>
+Yuval Kogman <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-	Copyright (c) 2008 Yuval Kogman. All rights reserved
-	This program is free software; you can redistribute
-	it and/or modify it under the same terms as Perl itself.
+This software is copyright (c) 2012 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
