@@ -1,11 +1,13 @@
-#!/usr/bin/perl
-
 package Data::Stream::Bulk::Array;
+{
+  $Data::Stream::Bulk::Array::VERSION = '0.08';
+}
 use Moose;
+# ABSTRACT: L<Data::Stream::Bulk> wrapper for simple arrays.
 
 use namespace::clean -except => 'meta';
 
-with qw(Data::Stream::Bulk) => { excludes => [qw/loaded filter list_cat/] };
+with qw(Data::Stream::Bulk) => { -excludes => [qw/loaded filter list_cat/] };
 
 has array => (
 	isa => "ArrayRef",
@@ -66,9 +68,9 @@ sub loaded { 1 }
 
 __PACKAGE__->meta->make_immutable;
 
-__PACKAGE__
+__PACKAGE__;
+
 
-__END__
 
 =pod
 
@@ -76,6 +78,10 @@ __END__
 
 Data::Stream::Bulk::Array - L<Data::Stream::Bulk> wrapper for simple arrays.
 
+=head1 VERSION
+
+version 0.08
+
 =head1 SYNOPSIS
 
 	return Data::Stream::Bulk::Array->new(
@@ -126,4 +132,19 @@ Returns true
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
