@@ -1,11 +1,13 @@
-#!/usr/bin/perl
-
 package Data::Stream::Bulk::Callback;
+{
+  $Data::Stream::Bulk::Callback::VERSION = '0.08';
+}
 use Moose;
+# ABSTRACT: Callback based bulk iterator
 
 use namespace::clean -except => 'meta';
 
-with qw(Data::Stream::Bulk::DoneFlag) => { excludes => [qw(is_done finished)] };
+with qw(Data::Stream::Bulk::DoneFlag) => { -excludes => [qw(is_done finished)] };
 
 has callback => (
 	isa => "CodeRef|Str",
@@ -22,9 +24,9 @@ sub get_more {
 
 __PACKAGE__->meta->make_immutable;
 
-__PACKAGE__
+__PACKAGE__;
+
 
-__END__
 
 =pod
 
@@ -32,6 +34,10 @@ __END__
 
 Data::Stream::Bulk::Callback - Callback based bulk iterator
 
+=head1 VERSION
+
+version 0.08
+
 =head1 SYNOPSIS
 
 	Data::Stream::Bulk::Callback->new(
@@ -73,5 +79,19 @@ Reinvokes C<callback>.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
