@@ -1,11 +1,13 @@
-#!/usr/bin/perl
-
 package Data::Stream::Bulk::DBI;
+{
+  $Data::Stream::Bulk::DBI::VERSION = '0.08';
+}
 use Moose;
+# ABSTRACT: N-at-a-time iteration of L<DBI> statement results.
 
 use namespace::clean -except => 'meta';
 
-with qw(Data::Stream::Bulk::DoneFlag) => { excludes => [qw/is_done all finished/] };
+with qw(Data::Stream::Bulk::DoneFlag) => { -excludes => [qw/is_done all finished/] };
 
 has sth => (
 	isa => "Object",
@@ -42,9 +44,9 @@ sub all {
 
 __PACKAGE__->meta->make_immutable;
 
-__PACKAGE__
+__PACKAGE__;
+
 
-__END__
 
 =pod
 
@@ -52,6 +54,10 @@ __END__
 
 Data::Stream::Bulk::DBI - N-at-a-time iteration of L<DBI> statement results.
 
+=head1 VERSION
+
+version 0.08
+
 =head1 SYNOPSIS
 
 	use Data::Stream::Bulk::DBI;
@@ -110,5 +116,19 @@ C<max_rows>).
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
