@@ -1,11 +1,13 @@
-#!/usr/bin/perl
-
 package Data::Stream::Bulk::DBIC;
+{
+  $Data::Stream::Bulk::DBIC::VERSION = '0.08';
+}
 use Moose;
+# ABSTRACT: Iterate DBIC resultsets with L<Data::Stream::Bulk>
 
 use namespace::clean -except => 'meta';
 
-with qw(Data::Stream::Bulk::DoneFlag) => { excludes => [qw(is_done finished)] };
+with qw(Data::Stream::Bulk::DoneFlag) => { -excludes => [qw(is_done finished)] };
 
 has resultset => (
 	isa => "Object",
@@ -26,9 +28,9 @@ sub get_more {
 
 __PACKAGE__->meta->make_immutable;
 
-__PACKAGE__
+__PACKAGE__;
+
 
-__END__
 
 =pod
 
@@ -36,6 +38,10 @@ __END__
 
 Data::Stream::Bulk::DBIC - Iterate DBIC resultsets with L<Data::Stream::Bulk>
 
+=head1 VERSION
+
+version 0.08
+
 =head1 SYNOPSIS
 
 	Data::Stream::Bulk::DBIC->new(
@@ -66,4 +72,19 @@ Returns a single row. In the future this should return more than one row.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
