@@ -1,7 +1,9 @@
-#!/usr/bin/perl
-
 package Data::Stream::Bulk::DoneFlag;
+{
+  $Data::Stream::Bulk::DoneFlag::VERSION = '0.08';
+}
 use Moose::Role;
+# ABSTRACT: Implement the C<is_done> method in terms of a flag
 
 use namespace::clean -except => 'meta';
 
@@ -40,16 +42,19 @@ sub next {
 	}
 }
 
-__PACKAGE__
+__PACKAGE__;
+
 
-__END__
 
 =pod
 
 =head1 NAME
 
-Data::Stream::Bulk::DoneFlag - Implement the C<is_done> method in terms of a
-flag
+Data::Stream::Bulk::DoneFlag - Implement the C<is_done> method in terms of a flag
+
+=head1 VERSION
+
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -110,4 +115,19 @@ are left.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
