@@ -1,11 +1,13 @@
-#!/usr/bin/perl
-
 package Data::Stream::Bulk::Nil;
+{
+  $Data::Stream::Bulk::Nil::VERSION = '0.08';
+}
 use Moose;
+# ABSTRACT: An empty L<Data::Stream::Bulk> iterator
 
 use namespace::clean -except => 'meta';
 
-with qw(Data::Stream::Bulk) => { excludes => [qw/loaded filter list_cat all items/] };
+with qw(Data::Stream::Bulk) => { -excludes => [qw/loaded filter list_cat all items/] };
 
 sub items { return () }
 
@@ -28,9 +30,9 @@ sub loaded { 1 }
 
 __PACKAGE__->meta->make_immutable;
 
-__PACKAGE__
+__PACKAGE__;
+
 
-__END__
 
 =pod
 
@@ -38,6 +40,10 @@ __END__
 
 Data::Stream::Bulk::Nil - An empty L<Data::Stream::Bulk> iterator
 
+=head1 VERSION
+
+version 0.08
+
 =head1 SYNOPSIS
 
 	return Data::Stream::Bulk::Nil->new; # empty set
@@ -78,5 +84,19 @@ Returns true.
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
