@@ -1,9 +1,11 @@
-#!/usr/bin/perl
-
 package Data::Stream::Bulk::Util;
+{
+  $Data::Stream::Bulk::Util::VERSION = '0.08';
+}
 
 use strict;
 use warnings;
+# ABSTRACT: Utility functions for L<Data::Stream::Bulk>
 
 use Data::Stream::Bulk::Nil;
 use Data::Stream::Bulk::Array;
@@ -33,9 +35,9 @@ sub unique ($) {
 	shift->filter(sub { [ grep { !$seen{ref($_) ? refaddr($_) : $_}++ } @$_ ] }); # FIXME Hash::Util::FieldHash::Compat::id()?
 }
 
-__PACKAGE__
+__PACKAGE__;
+
 
-__END__
 
 =pod
 
@@ -43,6 +45,10 @@ __END__
 
 Data::Stream::Bulk::Util - Utility functions for L<Data::Stream::Bulk>
 
+=head1 VERSION
+
+version 0.08
+
 =head1 SYNOPSIS
 
 	use Data::Stream::Bulk::Util qw(array);
@@ -99,5 +105,19 @@ References are keyed by their refaddr (see L<Hash::Util::FieldHash/id>).
 
 =back
 
+=head1 AUTHOR
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Yuval Kogman.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
